@@ -12,7 +12,7 @@ import collections
 from functools import wraps
 import logging
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 # stuff for Python 3 compatibility
 try:
@@ -24,6 +24,12 @@ try:
     reduce
 except NameError:
     from functools import reduce
+    
+try:
+    basestring
+except NameError:
+    basestring = str
+    
 
 logger = logging.getLogger("lazyarray")
 
@@ -173,7 +179,7 @@ class larray(object):
             if isinstance(op[1], larray):
                 op[1].shape = value
     shape = property(fget=lambda self: self._shape,
-                     fset=_set_shape)
+                     fset=_set_shape, doc="Shape of the array")
 
     @property
     @requires_shape
